@@ -6,6 +6,7 @@ from chat2edit.models.execution_block import ExecutionBlock
 from chat2edit.models.execution_error import ExecutionError
 from chat2edit.models.execution_feedback import ExecutionFeedback
 from chat2edit.models.exemplar import Exemplar
+from chat2edit.models.llm_message import LlmMessage
 from chat2edit.models.prompt_cycle import PromptCycle
 from chat2edit.models.prompt_exchange import PromptExchange
 
@@ -18,6 +19,7 @@ __all__ = [
     "ExecutionError",
     "ExecutionFeedback",
     "Exemplar",
+    "LlmMessage",
     "PromptCycle",
     "PromptExchange",
 ]
