@@ -1,6 +1,5 @@
 from chat2edit.prompting.llms.impl.google_llm import GoogleLlm
 from chat2edit.prompting.llms.impl.openai_llm import OpenAILlm
 from chat2edit.prompting.llms.llm import Llm
-from chat2edit.prompting.llms.llm_message import LlmMessage
 
-__all__ = ["GoogleLlm", "OpenAILlm", "Llm", "LlmMessage"]
+__all__ = ["GoogleLlm", "OpenAILlm", "Llm"]
