@@ -2,7 +2,7 @@ from abc import ABC, abstractmethod
 from typing import Any, Dict, List, Optional
 
 from chat2edit.models import ChatCycle, Exemplar
-from chat2edit.prompting.llms import LlmMessage
+from chat2edit.models import LlmMessage
 
 
 class PromptingStrategy(ABC):
